pub fn set_resume_command_template(template: String)Expand description
Stores the process invocation with the range positional replaced by {range}, used to
print an accurate resume command in fatal error messages. Set once at CLI parse time and
deliberately not cleared by init (it describes the process, not the run).